Skip to contents

Usage

categorize_prism(
  value,
  location,
  disease,
  as_of = lubridate::today(),
  prism_bin_names = NULL,
  signal = lifecycle::deprecated()
)

Arguments

value

numeric vector to categorize

location

vector of location of length equal to value or a single location for all value.

disease

vector of disease of length equal to value or a single disease for all value.

as_of

Retrieve cutpoints that were in place as of this date. Defaults to today (current cutpoints).

prism_bin_names

Bin names for the PRISM bins, in order from lowest to highest. Must be a vector of length 5. list(prism_bin_names) will be passed as the label_sets argument to categorize_vector(). If NULL (the default), derived from the cutpoint names by dropping the upper bound and converting to title case, giving "Very Low", "Low", "Moderate", "High", and "Very High".

signal

surveillance signal for which to return the cutpoints. Options are "NSSP" (proportions of emergency department visits) and "NHSN" (weekly hospital admissions per 100k population). If not specified, default to "NSSP" with a deprecation warning.

Value

A factor vector of category labels, equal in length to the input vector value.