Skip to contents

Cutpoint sets are specific to a particular combination of disease, location, and signal. They are also vintaged; you can look up the set of cutpoints that were in place for a given disease, location, and signal as of any particular date (with an error if none were defined as of that date).

Usage

get_prism_cutpoints(
  location,
  disease,
  signal = lifecycle::deprecated(),
  as_of = lubridate::today()
)

Arguments

location

location for which to return the cutpoints, as a two-letter abbreviation. Use us_location_recode with location_output_format = "abbr" to convert to this format.

disease

disease for which to return the cutpoints. Options are "ARI" (NSSP-only), "COVID-19", "Influenza", and "RSV".

signal

surveillance signal for which to return the cutpoints. Options are "NSSP" (proportions of emergency department visits) and "NHSN" (weekly hospital admissions per 100k population). If not specified, default to "NSSP" with a deprecation warning.

as_of

Retrieve cutpoints that were in place as of this date. Defaults to today (current cutpoints).

Value

The cutpoints, as a list of vectors, named very_low, low, moderate, high, very_high, and upper_bound for every signal.

Details

This function is vectorized. It recycles the disease, location, signal``, and as_of` arguments to a common length and returns a corresponding list of cutpoint vectors.

Examples

get_prism_cutpoints("WA", "Influenza", signal = "NHSN")
#> [[1]]
#>    very_low         low    moderate        high   very_high upper_bound 
#>    0.000000    1.036759    2.376762    8.466189   11.956217         Inf 
#> 

get_prism_cutpoints(c("US", "WA"), "COVID-19", signal = "NSSP")
#> [[1]]
#>    very_low         low    moderate        high   very_high upper_bound 
#>  0.00000000  0.00366241  0.01143741  0.01921242  0.02698742  1.00000000 
#> 
#> [[2]]
#>    very_low         low    moderate        high   very_high upper_bound 
#> 0.000000000 0.003500959 0.010506555 0.017512151 0.024517747 1.000000000 
#> 

get_prism_cutpoints(
  c("US", "WA"),
  c("COVID-19", "RSV"),
  signal = "NSSP",
  as_of = as.Date("2025-01-01")
)
#> [[1]]
#>    very_low         low    moderate        high   very_high upper_bound 
#> 0.000000000 0.006015091 0.017041933 0.028068775 0.039095617 1.000000000 
#> 
#> [[2]]
#>     very_low          low     moderate         high    very_high  upper_bound 
#> 0.0000000000 0.0004551485 0.0061158985 0.0117766486 0.0174373986 1.0000000000 
#> 

get_prism_cutpoints("WA", "Influenza", signal = c("NSSP", "NHSN"))
#> [[1]]
#>    very_low         low    moderate        high   very_high upper_bound 
#> 0.000000000 0.003652557 0.023209394 0.042766232 0.062323070 1.000000000 
#> 
#> [[2]]
#>    very_low         low    moderate        high   very_high upper_bound 
#>    0.000000    1.036759    2.376762    8.466189   11.956217         Inf 
#>