Skip to contents

Returns the population denominator PRISM used to derive its rate-scale activity level cutpoints.

Usage

get_prism_reference_population(location, as_of = lubridate::today())

Arguments

location

location(s) for which to return the reference population, as a two-letter abbreviation. Use us_location_recode with location_output_format = "abbr" to convert to this format.

as_of

single date for which the reference population is valid, applied to every location. Defaults to today.

Value

The reference populations, as a numeric vector with one entry per location.

Examples

get_prism_reference_population("WA")
#> [1] 7764081

get_prism_reference_population(c("WA", "CA"))
#> [1]  7764081 38828183

get_prism_reference_population(
  "WA",
  as.Date("2026-08-13"))
#> [1] 7764081