Skip to contents

A tibble of PRISM respiratory virus activity level thresholds (one row per combination of as_of, signal, disease, and location):

as_of

Date from which the row's thresholds are valid.

signal

Surveillance signal, nssp (emergency department visit thresholds, as proportions of visits, bounded above by 1) or nhsn (hospital admission thresholds, as weekly admissions per 100K population).

disease

Influenza, COVID-19, RSV, or ARI (acute respiratory infections).

location

US jurisdiction or the United States as a whole, using two-letter codes (the values of abbr) in us_location_table.

values

List column of named numeric vectors of cutpoints, named very_low, low, moderate, high, very_high, and upper_bound.

Usage

prism_thresholds

Format

An object of class tbl_df (inherits from tbl, data.frame) with 589 rows and 5 columns.

<data-raw/prism_thresholds.R>