Skip to contents

[Deprecated]

Usage

us_location_pop

Format

A tibble with 53 rows and 2 columns:

name

Full name of the location

population

Estimated population count

Census Population Estimates Program via tidycensus::get_estimates()

data-raw/us_location_pop.R

Details

A table of population estimates for the United States as a whole and for US states, using the most recent Census Population Estimates Program vintage available when the dataset was generated.

Deprecation

This table is a single, unvintaged snapshot of whichever Census vintage was current when it was last generated (cannot be aligned to point in time).