Categorize a numeric vector into PRISM activity level bins.
Source:R/categorize_prism.R
categorize_prism.RdUses categorize_vector() and get_prism_cutpoints().
Usage
categorize_prism(
value,
location,
disease,
as_of = lubridate::today(),
prism_bin_names = NULL,
signal = lifecycle::deprecated()
)Arguments
- value
numeric vector to categorize
- location
vector of location of length equal to
valueor a single location for allvalue.- disease
vector of disease of length equal to
valueor a single disease for allvalue.- as_of
Retrieve cutpoints that were in place as of this date. Defaults to today (current cutpoints).
- prism_bin_names
Bin names for the PRISM bins, in order from lowest to highest. Must be a vector of length 5.
list(prism_bin_names)will be passed as thelabel_setsargument tocategorize_vector(). IfNULL(the default), derived from the cutpoint names by dropping the upper bound and converting to title case, giving"Very Low","Low","Moderate","High", and"Very High".- signal
surveillance signal for which to return the cutpoints. Options are
"NSSP"(proportions of emergency department visits) and"NHSN"(weekly hospital admissions per 100k population). If not specified, default to"NSSP"with a deprecation warning.