Categorize a vector of value into PRISM activity level bins.
Source:R/categorize_prism.R
categorize_prism.RdUses categorize_vector() and get_prism_cutpoints().
Usage
categorize_prism(
value,
location,
disease,
as_of = lubridate::today(),
prism_bin_names = NULL,
signal = lifecycle::deprecated()
)Arguments
- value
value to categorize
- location
vector of location of length equal to
valueor a single location for allvalue.- disease
vector of disease of length equal to
valueor a single disease for allvalue.- as_of
single date for which the cutpoints are valid, applied to every
location,disease, andsignal. Defaults to today.- prism_bin_names
Bin names for the PRISM bins, in order from lowest to highest. Must be a vector of length 5.
list(prism_bin_names)will be passed as thelabel_setsargument tocategorize_vector(). IfNULL(the default), derived from the cutpoint names by dropping the upper bound and converting to title case, giving"Very Low","Low","Moderate","High", and"Very High".- signal
surveillance signal(s) for which to return the cutpoints. One of
"NSSP"(proportions of emergency department visits) or"NHSN"(weekly hospital admissions per 100k population), or an array of those values. If not given, defaults to"NSSP"with a deprecation warning (a future version will require it).