Skip to contents

Get PRISM activity level cutpoints given disease and location.

Usage

get_prism_cutpoints(
  location,
  disease,
  as_of = lubridate::today(),
  signal = lifecycle::deprecated()
)

Arguments

location

location(s) for which to return the cutpoints, as a two-letter abbreviation. Use us_location_recode with location_output_format = "abbr" to convert to this format.

disease

disease(s) for which to return the cutpoints. One of "ARI", "COVID-19", "Influenza", or "RSV", or an array of those values. NHSN provides no "ARI" thresholds.

as_of

single date for which the cutpoints are valid, applied to every location, disease, and signal. Defaults to today.

signal

surveillance signal(s) for which to return the cutpoints. One of "NSSP" (proportions of emergency department visits) or "NHSN" (weekly hospital admissions per 100k population), or an array of those values. If not given, defaults to "NSSP" with a deprecation warning (a future version will require it).

Value

The cutpoints, as a list of vectors, named very_low, low, moderate, high, very_high, and upper_bound for every signal.

Examples

get_prism_cutpoints("WA", "Influenza", signal = "NHSN")
#> [[1]]
#>    very_low         low    moderate        high   very_high upper_bound 
#>    0.000000    1.036759    2.376762    8.466189   11.956217         Inf 
#> 

get_prism_cutpoints(c("US", "WA"), "COVID-19", signal = "NSSP")
#> [[1]]
#>    very_low         low    moderate        high   very_high upper_bound 
#>  0.00000000  0.00536526  0.01655255  0.02773983  0.03892712  1.00000000 
#> 
#> [[2]]
#>    very_low         low    moderate        high   very_high upper_bound 
#> 0.000000000 0.007394318 0.021019610 0.034644902 0.048270194 1.000000000 
#> 

get_prism_cutpoints(
  c("US", "WA"),
  c("COVID-19", "RSV"),
  as.Date("2025-01-01"),
  signal = "NSSP"
)
#> [[1]]
#>    very_low         low    moderate        high   very_high upper_bound 
#> 0.000000000 0.006015091 0.017041933 0.028068775 0.039095617 1.000000000 
#> 
#> [[2]]
#>     very_low          low     moderate         high    very_high  upper_bound 
#> 0.0000000000 0.0004551485 0.0061158985 0.0117766486 0.0174373986 1.0000000000 
#> 

get_prism_cutpoints("WA", "Influenza", signal = c("NSSP", "NHSN"))
#> [[1]]
#>    very_low         low    moderate        high   very_high upper_bound 
#> 0.000000000 0.002766458 0.030385827 0.058005195 0.085624564 1.000000000 
#> 
#> [[2]]
#>    very_low         low    moderate        high   very_high upper_bound 
#>    0.000000    1.036759    2.376762    8.466189   11.956217         Inf 
#>