Get the PRISM reference population for a location.
Source:R/prism_reference_population.R
get_prism_reference_population.RdReturns the population denominator PRISM used to derive its rate-scale activity level cutpoints.
Usage
get_prism_reference_population(location, as_of = lubridate::today())Arguments
- location
location(s) for which to return the reference population, as a two-letter abbreviation. Use us_location_recode with
location_output_format = "abbr"to convert to this format.- as_of
single date for which the reference population is valid, applied to every
location. Defaults to today.