Skip to contents

A table of population estimates for the United States as a whole and for US states, using the most recent Census Population Estimates Program vintage available when the dataset was generated.

Usage

us_location_pop

Format

A tibble with 53 rows and 2 columns:

name

Full name of the location

population

Estimated population count

Census Population Estimates Program via tidycensus::get_estimates()

data-raw/us_location_pop.R